window.ClockTime = function(options) {
	return this.init(options);
}
ClockTime.config = {
tickDelay: 1000,
longTickDelay: 15000,
defaultRadius: 75,          // Standard Durchmesser
renderRadius: 100, 
defaultSkin: "Obj14_2a",     // Standard Skin
showSecs: true,
showAmPm: true,
	skins:  {
		Obj14_2a: {
			outerBorder: { lineWidth: 4, radius:97, color: "black", alpha: 1 },
			smallIndicator: { lineWidth: 4, startAt: 89, endAt: 93, color: "black", alpha: 1 },
			largeIndicator: { lineWidth: 8, startAt: 80, endAt: 93, color: "black", alpha: 1 },
			hourHand: { lineWidth: 12, startAt: -15, endAt: 60, color: "black", alpha: 1 },
			minuteHand: { lineWidth: 10, startAt: -15, endAt: 85, color: "black", alpha: 1 },
			secondHand: { lineWidth: 4, startAt: -20, endAt: 85, color: "red", alpha: 1 },
			secondDecoration: { lineWidth: 2, startAt: 70, radius: 8, fillColor: "red", color: "red", alpha: 1 }
		},
		Obj14_2b: {
			outerBorder:      { lineWidth: 185, radius: 1, color: "#E5ECF9", alpha: 1 },
			smallIndicator:   { lineWidth: 2, startAt: 89, endAt: 94, color: "#3366CC", alpha: 1 },
			largeIndicator:   { lineWidth: 4, startAt: 83, endAt: 94, color: "#3366CC", alpha: 1 },
			hourHand:         { lineWidth: 5, startAt: 0, endAt: 60, color: "black", alpha: 1 },
			minuteHand:       { lineWidth: 4, startAt: 0, endAt: 80, color: "black", alpha: 1 },
			secondHand:       { lineWidth: 1, startAt: -20, endAt: 85, color: "red", alpha: .85 },
			secondDecoration: { lineWidth: 3, startAt: 0, radius: 2, fillColor: "black", color: "black", alpha: 1 }
		},
		Obj14_2c: {
			outerBorder:      { lineWidth: 100, radius: 140, color: "#99FFFF", alpha: 0.2 },
			smallIndicator:   { lineWidth: 300, startAt: 50, endAt: 70, color: "black", alpha: 0.1 },
			largeIndicator:   { lineWidth: 5, startAt: 80, endAt: 95, color: "black", alpha: 0.65 },
			hourHand:         { lineWidth: 4, startAt: 0, endAt: 65, color: "black", alpha: 0.9 },
			minuteHand:       { lineWidth: 3, startAt: 0, endAt: 80, color: "black", alpha: 0.85 },
			secondHand:       { lineWidth: 1, startAt: 0, endAt: 90, color: "black", alpha: 1 },
			secondDecoration: { lineWidth: 2, startAt: 5, radius: 10, fillColor: "black", color: "black", alpha: 1 }
		},
		Obj14_2d: {
			outerBorder:      { lineWidth: 100, radius: 25, color: "blue", alpha: 0.25 },
			smallIndicator:   { lineWidth: 3, startAt: 90, endAt: 95, color: "#3366CC", alpha: 1 },
			largeIndicator:   { lineWidth: 4, startAt: 75, endAt: 95, color: "#3366CC", alpha: 1 },
			hourHand:         { lineWidth: 4, startAt: 0, endAt: 60, color: "black", alpha: 1 },
			minuteHand:       { lineWidth: 3, startAt: 0, endAt: 85, color: "black", alpha: 1 },
			secondHand:       { lineWidth: 12, startAt: 75, endAt: 90, color: "red", alpha: 0.8 },
			secondDecoration: { lineWidth: 3, startAt: 0, radius: 4, fillColor: "black", color: "black", alpha: 1 }
		},
	},
	isIE: !!document.all,
	clockTracker: {},
	noIdCount: 0
};
ClockTime.prototype = {
	init: function(options) {
		this.canvasId       = options.canvasId;
		this.skinId         = options.skinId || ClockTime.config.defaultSkin;
		this.displayRadius  = options.displayRadius || ClockTime.config.defaultRadius;
		this.showSecondHand = typeof options.showSecondHand == "boolean" ? options.showSecondHand : true;
		this.gmtOffset      = (options.gmtOffset != null && options.gmtOffset != '') ? parseFloat(options.gmtOffset) : null;
		this.showDigital    = typeof options.showDigital == "boolean" ? options.showDigital : false;
		this.logClock       = typeof options.logClock == "boolean" ? options.logClock : false;
		this.logClockRev    = typeof options.logClock == "boolean" ? options.logClockRev : false;
		this.tickDelay      = ClockTime.config[ this.showSecondHand ? "tickDelay" : "longTickDelay" ];
		this.canvas = document.getElementById(this.canvasId);
		this.canvas.setAttribute("width",this.displayRadius*2);
		this.canvas.setAttribute("height",this.displayRadius*2);
		this.canvas.style.width = this.displayRadius*2 + "px";
		this.canvas.style.height = this.displayRadius*2 + "px";
		this.renderRadius = ClockTime.config.renderRadius;
		this.scale = this.displayRadius / this.renderRadius;
		this.ctx = this.canvas.getContext("2d");
		this.ctx.scale(this.scale,this.scale);
		ClockTime.config.clockTracker[this.canvasId] = this;
		this.tick();
		return this;
	},
	fullCircleAt: function(x,y,skin) {
		this.ctx.save();
		this.ctx.globalAlpha = skin.alpha;
		this.ctx.lineWidth = skin.lineWidth;
		if (!ClockTime.config.isIE) {
			this.ctx.beginPath();
		}
		if (ClockTime.config.isIE) {
			this.ctx.lineWidth = this.ctx.lineWidth * this.scale;
		}
		this.ctx.arc(x, y, skin.radius, 0, 2*Math.PI, false);
		if (ClockTime.config.isIE) {
			this.ctx.arc(x, y, skin.radius, -0.1, 0.1, false);
		}
		if (skin.fillColor) {
			this.ctx.fillStyle = skin.fillColor
			this.ctx.fill();
		}
		else {
			this.ctx.strokeStyle = skin.color;
			this.ctx.stroke();
		}
		this.ctx.restore();
	},
	drawTextAt: function(theText,x,y) {
		this.ctx.save();
		this.ctx.font = '15px sans-serif';
		var tSize = this.ctx.measureText(theText);
		if (!tSize.height) tSize.height = 15;
		this.ctx.fillText(theText,x - tSize.width/2,y - tSize.height/2);
		this.ctx.restore();
	},
	lpad2: function(num) {
		return (num < 10 ? '0' : '') + num;
	},
	tickAngle: function(second) {
		var tweak = 3;
		if (this.logClock) {
			return second == 0 ? 0 : (Math.log(second*tweak) / Math.log(60*tweak));
		}
		else if (this.logClockRev) {
			second = (60 - second) % 60;
			return 1.0 - (second == 0 ? 0 : (Math.log(second*tweak) / Math.log(60*tweak)));
		}
		else {
			return second/60.0;
		}
	},
	canvasText: function(hour,min,sec) {
		var c = ClockTime.config;
		return '' +
		(c.showAmPm ? ((hour%12)==0 ? 12 : (hour%12)) : hour) + ':' +
		this.lpad2(min) +
		(c.showSecs ? ':' + this.lpad2(sec) : '') +
		(c.showAmPm ? (hour < 12 ? ' am' : ' pm') : '')
		;
	},
	radialLineAtAngle: function(angleFraction,skin) {
		this.ctx.save();
		this.ctx.translate(this.renderRadius,this.renderRadius);
		this.ctx.rotate(Math.PI * (2.0 * angleFraction - 0.5));
		this.ctx.globalAlpha = skin.alpha;
		this.ctx.strokeStyle = skin.color;
		this.ctx.lineWidth = skin.lineWidth;
		if (ClockTime.config.isIE)
		this.ctx.lineWidth = this.ctx.lineWidth * this.scale;
		if (skin.radius) {
		this.fullCircleAt(skin.startAt,0,skin)
	}
	else {
		this.ctx.beginPath();
		this.ctx.moveTo(skin.startAt,0)
		this.ctx.lineTo(skin.endAt,0);
		this.ctx.stroke();
	}
	this.ctx.restore();
},
render: function(hour,min,sec) {
	var skin = ClockTime.config.skins[this.skinId];
	if (!skin) skin = ClockTime.config.skins[ClockTime.config.defaultSkin];
	this.ctx.clearRect(0,0,this.renderRadius*2,this.renderRadius*2);
	if (skin.outerBorder)
	this.fullCircleAt(this.renderRadius,this.renderRadius,skin.outerBorder);
	for (var i=0;i<60;i++) {
		(i%5)  && skin.smallIndicator && this.radialLineAtAngle(this.tickAngle(i),skin.smallIndicator);
		!(i%5) && skin.largeIndicator && this.radialLineAtAngle(this.tickAngle(i),skin.largeIndicator);
	}
	if (this.showDigital) {
		this.drawTextAt(
			this.canvasText(hour,min,sec),
			this.renderRadius,
			this.renderRadius+this.renderRadius/2
		);
	}
	if (skin.hourHand)
	this.radialLineAtAngle(this.tickAngle(((hour%12)*5 + min/12.0)),skin.hourHand);
	if (skin.minuteHand)
	this.radialLineAtAngle(this.tickAngle((min + sec/60.0)),skin.minuteHand);
	if (this.showSecondHand && skin.secondHand)
	this.radialLineAtAngle(this.tickAngle(sec),skin.secondHand);
	if (!ClockTime.config.isIE && this.showSecondHand && skin.secondDecoration)
	this.radialLineAtAngle(this.tickAngle(sec),skin.secondDecoration);
},
refreshDisplay: function() {
	var now = new Date();
	if (this.gmtOffset != null) {
		var offsetNow = new Date(now.valueOf() + (this.gmtOffset * 1000 * 60 * 60));
		this.render(offsetNow.getUTCHours(),offsetNow.getUTCMinutes(),offsetNow.getUTCSeconds());
	}
	else {
		this.render(now.getHours(),now.getMinutes(),now.getSeconds());
		}
	},
	nextTick: function() {
		setTimeout("ClockTime.config.clockTracker['"+this.canvasId+"'].tick()",this.tickDelay);
	},
	stillHere: function() {
		return document.getElementById(this.canvasId) != null;
	},
	tick: function() {
		if (this.stillHere()) {
			this.refreshDisplay()
			this.nextTick();
		}
	}
};
ClockTime.findAndCreateClocks = function() {
	var canvases = document.getElementsByTagName("canvas");
	for (var i=0;i<canvases.length;i++) {
			var fields = canvases[i].className.split(" ")[0].split(":");
			if (fields[0] == "ClockTime") {
				if (!canvases[i].id) {
					canvases[i].id = '_ClockTime_auto_id_' + ClockTime.config.noIdCount++;
				}
				new ClockTime({
				canvasId:       canvases[i].id,
				skinId:         fields[1],
				displayRadius:  fields[2],
				showSecondHand: fields[3]!='noSeconds',
				gmtOffset:      fields[4],
				showDigital:    fields[5]=='showDigital',
				logClock:       fields[6]=='logClock',
				logClockRev:    fields[6]=='logClockRev'
			});
		}
	}
};
if (window.jQuery) jQuery(document).ready(ClockTime.findAndCreateClocks);

